==> haskell-prim-uniq-0.2-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-IAZjMn0JdPeH4a6JiCPkh2
key:                  prim-uniq-0.2-IAZjMn0JdPeH4a6JiCPkh2
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  1a152529885dcdd44b4ee6cc3ff529d0
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-IAZjMn0JdPeH4a6JiCPkh2
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-9LJbDSR4EEc8lOUXPwVu95
    primitive-0.9.0.0-2SWzXeJZNqNGCC3BQBwQzS

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prim-uniq-0.2-181-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-EwcfnrVoFJfAmDuj6CmLNK
key:                  prim-uniq-0.2-EwcfnrVoFJfAmDuj6CmLNK
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  51fe4571c6f75255a2bc810647d664c8
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-EwcfnrVoFJfAmDuj6CmLNK
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-J23rf623gXt8SpCJzy9v38
    primitive-0.9.0.0-Ldr1crf6mT98Jp7aevHFeM

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
